/*
DL2 Monitor: ./pa/ether2.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (ether2): Packet Type ether (local)
 * creates the Pa_Packet object pa_ether2: see pa.h for details.
 * Frame format of DIX Ethernet Standarad (Ethernet II).
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History 
 * 20020410  attention to reserved verbose flags.
 * 20020330  created from scratch
 * $Id: ether2.h,v 1.3 2002/04/10 10:36:26 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __ETHER2_H__
# define __ETHER2_H__
# include "pa/pa.h"

static Pa_Config pa_ether2_field[] = {
  {"destination-addr","DA",0},
  {"source-addr","SA",1},
  {"ether-type","ET",2},
  {"payload-length","FL",3},
  {"payload-data","FD",4},
  {"checksum","CS",5},
  {"follow-frame","",6},
  {"follow-pppoe","",7},
  {NULL,NULL,-1}
};
const Pa_Packet pa_ether2 = {"ether2",pa_ether2_field};

# define ETHER2_Mdestination_addr	0x00000001
# define ETHER2_Msource_addr		0x00000002
# define ETHER2_Mether_type		0x00000004
# define ETHER2_Mpayload_length		0x00000008
# define ETHER2_Mpayload_data		0x00000010
# define ETHER2_Mchecksum		0x00000020
# define ETHER2_Mfollow_frame		0x00000040
# define ETHER2_Mfollow_pppoe		0x00000080
# define ETHER2_Mdefault		PA_VMdefault
# define ETHER2_Mpacket_length		PA_VMpacket_length

# define ETHER2_F(i)			pa_ether2_field[i].oname
# define ETHER2_Fdestination_addr	ETHER2_F(0)
# define ETHER2_Fsource_addr		ETHER2_F(1)
# define ETHER2_Fether_type		ETHER2_F(2)
# define ETHER2_Fpayload_length		ETHER2_F(3)
# define ETHER2_Fpayload_data		ETHER2_F(4)
# define ETHER2_Fchecksum		ETHER2_F(5)
# define ETHER2_Fpacket_length		PA_VFpacket_length
//#undef ETHER2_F

# endif /*__ETHER2_H__*/
